package com.example;



import java.util.HashMap;

/**
 * 操作消息提醒
 *
 * @author haiwei
 */
public class MyResult extends HashMap<String, Object>
{


    /** 状态码 */
    public static final String CODE_TAG = "status";

    /** 返回内容 */
    public static final String MSG_TAG = "msg";



    /**
     * 状态类型
     */
    public enum Type
    {
        /** 成功 */
        SUCCESS(200),

        /** 错误 */
        ERROR(500);
        private final int value;

        Type(int value)
        {
            this.value = value;
        }

        public int value()
        {
            return this.value;
        }
    }

    /**
     * 初始化一个新创建的 AjaxResult 对象，使其表示一个空消息。
     */
    public MyResult()
    {
    }

    /**
     * 初始化一个新创建的 AjaxResult 对象
     *
     * @param type 状态类型
     * @param msg 返回内容
     */
    public MyResult(Type type, String msg)
    {
        super.put(CODE_TAG, type.value);
        super.put(MSG_TAG, msg);
    }



    /**
     * 返回成功消息
     *
     * @return 成功消息
     */
    public static MyResult success()
    {
        return MyResult.success("操作成功");
    }

    /**
     * 返回成功数据
     *
     * @return 成功消息
     */
    public static MyResult success(Object data)
    {
        return MyResult.success("操作成功");
    }

    /**
     * 返回成功消息
     *
     * @param msg 返回内容
     * @return 成功消息
     */
    public static MyResult success(String msg)
    {
        return MyResult.success(msg);
    }






    /**
     * 返回错误消息
     *
     * @return
     */
    public static MyResult error()
    {
        return MyResult.error("操作失败");
    }

    /**
     * 返回错误消息
     *
     * @param msg 返回内容
     * @return 警告消息
     */
    public static MyResult error(String msg)
    {
        return MyResult.error(msg);
    }

}
